@@ -6,6 +6,9 @@ urlpatterns = patterns(
     url(r'^$',
         'index',
         name='lava.scheduler'),
+    url(r'^reports$',
+        'reports',
+        name='lava.scheduler.reports'),
     url(r'^active_jobs_json$',
         'index_active_jobs_json',
         name='lava.scheduler.active_jobs_json'),
